<?php

use SilverStripe\CMS\Model\SiteTree;
use SilverStripe\Forms\GridField\GridField;
use SilverStripe\Forms\GridField\GridFieldConfig_RecordEditor;

use SilverStripe\Forms\GridField\GridFieldConfig_RelationEditor;
use UndefinedOffset\SortableGridField\Forms\GridFieldSortableRows;

use SilverStripe\CMS\Controllers\ContentController;

//has_one Library
use SilverStripe\Assets\Image;
use SilverStripe\Assets\File;
use SilverStripe\AssetAdmin\Forms\UploadField;
use SilverStripe\AssetAdmin\Forms\PreviewImageField;
use SilverStripe\Forms\TextField;
use SilverStripe\Forms\HTMLEditor\HTMLEditorField;
use SilverStripe\ORM\PaginatedList;
use SilverStripe\Forms\CheckboxField;

//Search Area
use SilverStripe\Forms\Form;
use SilverStripe\Forms\FieldList;
use SilverStripe\Forms\FormAction;
use SilverStripe\ORM\ArrayList;
use SilverStripe\View\ArrayData;
use SilverStripe\Versioned\Versioned;
use SilverStripe\Security\Member;

class Genelgeler extends Page
{
    private static $db = [
		
	];

    private static $has_one = [

	];
	
	private static $has_many = [
		'GenelgelerItems' => GenelgelerItem::class,
    ];
	
	private static $owns = [
		'GenelgelerItems'
    ];
	
	public function getCMSFields()
    {
        $fields = parent::getCMSFields();
		
		$conf = GridFieldConfig_RecordEditor::create(10);
		$conf->addComponent(new GridFieldSortableRows('SortOrder'));

		$fields->addFieldToTab('Root.GenelgeEkle', new GridField('GenelgelerItems', 'Sayfa Listesi', $this->GenelgelerItems(), $conf));
		
        return $fields;
    }
	
	public function getResults($searchCriteria = []) 
{
    $start = ($this->getRequest()->getVar('start')) ? (int)$this->getRequest()->getVar('start') : 0;
    $limit = 10;
        
    $context = singleton('MyDataObject')->getCustomSearchContext();
    $query = $context->getQuery($searchCriteria, null, ['start'=>$start,'limit'=>$limit]);
    $records = $context->getResults($searchCriteria, null, ['start'=>$start,'limit'=>$limit]);
    
    if($records) {
        $records = new PaginatedList($records, $this->getRequest());
        $records->setPageStart($start);
        $records->setPageLength($limit);
        $records->setTotalItems($query->unlimitedRowCount());
    }
    
    return $records;
}

public function PaginatedPages()
	 {
		 $getImages = $this->owner->GenelgelerItems();
		 $paginatedImages = PaginatedList::create($getImages)->setPageLength(15);
		 return $paginatedImages;
	 }
	
}

class Genelgeler_Controller extends PageController {
	
	
	
	//Search Area ----------------------------------------------------------------------------------------------------------------------------------------------------------
	private static $allowed_actions = array(
        'SearchForm'
    );

    public function SearchForm()
    {
        $form = Form::create(
            $this,
            'SearchForm',
            FieldList::create(
                TextField::create('Keywords', '')
                        ->setAttribute('placeholder', _t('SearchPage.KEYWORDS', 'Keywords...'))
            ),
            FieldList::create(
                FormAction::create('SearchFormSubmit', _t('SearchPage.SEARCH', 'Search'))
            )
        );
        $form->setFormMethod('GET')
                 ->disableSecurityToken();

        return $form;
    }


    public function SearchFormSubmit($data, $form)
    {
        $rank[0] = 0;

        $strings = array(
        );

        /*
        *	Check if exist a perfect match and add a first rank
        *
        */
        $pages = Versioned::get_by_stage('GenelgelerItem', 'Live')->filterAny(
            array(
                'Title:PartialMatch:nocase' => $data['Keywords'],
                'Content:PartialMatch:nocase' => $data['Keywords'],
                'ContentSearch:PartialMatch:nocase' => $data['Keywords'],
            )
        );
        if (strlen($data['Keywords']) > 2) {
            if ($pages) {
                foreach ($pages as $page) {
                    if ($page) {
                        if (!isset($rank[$page->ID])) {
                            $rank[$page->ID]=0;
                        }
                        $rank[$page->ID] ++;
                    }
                }
            }
        }

        /*
        *	Check every words submitted and remove words containing 2 caracters or less. Return less results.
        *
        */
        $keywords = explode(" ", str_replace($strings, "", $data['Keywords']));

        foreach ($keywords as $value => $val) {
            if (strlen($val) > 2) {
                $pages = Versioned::get_by_stage('GenelgelerItem', 'Live')->filterAny(
                    array(
                        'Title:PartialMatch:nocase' => $val,
                        'Content:PartialMatch:nocase' => $data['Keywords'],
                        'ContentSearch:PartialMatch:nocase' => $val,
                    )
                );

                if ($pages) {
                    foreach ($pages as $page) {
                        if ($page) {
                            if (!isset($rank[$page->ID])) {
                                $rank[$page->ID]=0;
                            }
                            $rank[$page->ID] ++;
                        }
                    }
                }
            }
        }

        /*
        * Check pages add per rank.
        *
        */
        $results = new ArrayList();

        foreach ($rank as $value => $key) {
            $page = Versioned::get_by_stage('GenelgelerItem', 'Live')->exclude('ClassName', 'SilverStripe\ErrorPage\ErrorPage')->filter('ID', $value)->first();

            if ($page) {
                $results->push(
                    ArrayData::create(
                        array(
                            'Title' => $page->Title,
                            'Dates' => $page->Dates,
                            'Link' => $page->Link(),
                            'Rank' => $rank[$value],
                        )
                    )
                );
            }
        }

        /*
        * Sort higher is the score on top.
        *
        */
        $resultslist = $results->sort('Rank')->reverse();



        /*
        * Create a paginated pages results
        *
        */
        $paginatedProperties = PaginatedList::create(
            $resultslist,
            $this->getRequest()
        )->setPageLength(25);

        return array(
            'Results' => $paginatedProperties
        );
    }

    public function Keywords()
    {
        if (empty($_GET['Keywords'])) {
            return true;
        }
    }

    public function KeywordsGet()
    {
        return $_GET['Keywords'];
    }
	
}